@@ -76,7 +76,7 @@ epub_book = function(
 move_output = function(output) {
   if (is.null(opts$get('output_dir'))) return(output)
   output2 = output_path(output)
-  file.rename(output, output2)
+  file_rename(output, output2)
   output2
 }
 
